function PiPresence=PiPres(n0Vect,ARatio)
% Function calculates the probability of presence for each of the species
% in A0. The species' abundances are given in n0Vect and the elements in
% PiPresence corresponds to the same element giving a specific species in
% n0Vect.
% The probability of presence for a species in A depends only on its
% abundance in A0. Prob(presence) = 1 - Prob(absence). PiPresence is a
% column vector and n0Vect is a row vector.
% ARatio=A/A0

N0=sum(n0Vect)
S0=length(n0Vect)
S=0;

% Uses the simple result for A=A0/2 to calculate the probability of
% presence for each species with abundance given in n0Vect
if ARatio==0.5
    PiPresence=1-1./(n0Vect+1);
    S=sum(PiPresence);

% Calculates the probability of presence from Equation 7.48-50 in the book.
% These equations show how to solve for Pi(n) for any abundance n0 and in
% any A<A0.
else
    options = optimset('Display','off','TolX',1e-8,'TolFun',1e-8);
    guess=0.9;
    for i=1:S0
        n0=n0Vect(i);
        
        % The function used to find lambdaPi (or x=e^(-lambdaPi)) is given
        % below
        x=fsolve(@(x)fun(x,n0,S0,N0,ARatio),guess,options);
        PiPresence(i)=1-(1-x)/(1-x^(n0+1));
        % This command sums the probabilities of presence for all the
        % species. This is the expected number of species in A (and should
        % be close to the simulated average).
        S=S+PiPresence(i);
        % Uses the previous x to guess the next x in the solver for
        % lambdaPi
        guess=x;
    end
    
    
end % End if else

fprintf(['Expected S is ' num2str(S) '\n']);
PiPresence=PiPresence';     % Reshapes as column vector
end % End Function



% Function for calculating x=e^(-lambdaPi)
function F=fun(x,n0,S0,N0,ARatio)
    F=x/(1-x)-(n0+1)*x^(n0+1)/(1-x^(n0+1))-n0*ARatio;
end