function plotT
% Plots All the Paltridge Stability graphs

% ---------CONSTANTS----------------------------
% Constants used to calculate temperatures at equilibrium (all values are
% per square meter)
s=6e-8;
Op=200;
Oe=600;
Qstep=1;

% ---------SOLVING/PLOTTING FOR Qmax-----------------
% Calculates the Q, Qmax, that gives Te=Tp and the
% corresponding temperatures (should be equal!)
Qmax=(Oe-Op)/3
TeCross=((Oe-2*Qmax)/s).^(1/4)
TpCross=((Op+Qmax)/s).^(1/4)

% Span of Q in plot (heat output cannot exceed solar input at equator)
Q=0:Qstep:Qmax;

% Calculates equilibrium temperatures for given Q. This can be done independently for each region. Q is varied from 0 to
% Qmax. For each Q there is a unique equilbrium (Te',Tp'). For each
% equilibrium, (Q,Te',Tp') k is uniquely given via the relationship Q=k(Te-Tp).
% The corresponding k is calculated in the next step.
Te=((Oe-2*Q)/s).^(1/4);
Tp=((Op+Q)/s).^(1/4);
k=Q./(Te-Tp);

% Control that this are actual equilbria, by using the equilibrium equation
% with k(Te-Tp) instead of Q
check1=Op+k.*(Te-Tp)-s*Tp.^4;
check2=Oe-2*k.*(Te-Tp)-s*Te.^4;

% Writes the sum of all the terms of both equations to the screen
fprintf('Sum of deviations from equilibrium');
sum(check1)+sum(check2)

% Plots Te and Tp as functions of Q (low Q gives high Te and low Tp)
figure('Name','Te and Tp as functions of Q')
plot(Q,Te,Q,Tp);
xlabel('Q')
ylabel('Kelvin');
saveas(gcf,'T(Q).jpg');

% Plots Te, Tp and k as functions of Q (low Q gives high Te and low Tp)
figure('Name','Te,Tp and k as functions of Q')
plot(Q,Te,Q,Tp,Q,k);
xlabel('Q')
ylabel('Kelvin/k');
saveas(gcf,'T(Q)_k(Q).jpg');

% ---------SOLVING/PLOTTING FOR 95% Qmax-----------------
% Plots k as a function of Q alone up to 95% of Qmax
Q=0:Qstep:floor(0.95*Qmax);
Te=((Oe-2*Q)/s).^(1/4);
Tp=((Op+Q)/s).^(1/4);
k=Q./(Te-Tp);
figure('Name','k as function of Q')
plot(Q,k);
xlabel('Q')
ylabel('k');
saveas(gcf,'k(Q).jpg');

g=Q./10.*exp(Q/1000);
figure('Name', 'k compared')
plot(Q,k,Q,g)


% EIGENVALUES
Kp=1;
Ke=1;

% Eigenvalues
lambda1= -(Ke*k + 2*Kp*k - (16*Ke^2*Tp.^6*s^2 + 8*Ke^2*Tp.^3.*k*s + Ke^2*k.^2 - 32*Ke*Kp*Te.^3.*Tp.^3*s^2 - 8*Ke*Kp*Te.^3.*k*s - 16*Ke*Kp*Tp.^3.*k*s + 4*Ke*Kp*k.^2 + 16*Kp^2*Te.^6*s^2 + 16*Kp^2*Te.^3.*k*s + 4*Kp^2*k.^2).^(1/2) + 4*Ke*Tp.^3*s + 4*Kp*Te.^3*s)/(2*Ke*Kp);     
lambda2= -(Ke*k + 2*Kp*k + (16*Ke^2*Tp.^6*s^2 + 8*Ke^2*Tp.^3.*k*s + Ke^2*k.^2 - 32*Ke*Kp*Te.^3.*Tp.^3*s^2 - 8*Ke*Kp*Te.^3.*k*s - 16*Ke*Kp*Tp.^3.*k*s + 4*Ke*Kp*k.^2 + 16*Kp^2*Te.^6*s^2 + 16*Kp^2*Te.^3.*k*s + 4*Kp^2*k.^2).^(1/2) + 4*Ke*Tp.^3*s + 4*Kp*Te.^3*s)/(2*Ke*Kp);

    
% Plots the eigenvalues as function of Q (up to 95% of Qmax to avoid
% infinite values) and as function of k
figure('Name','Eigenvalues as functions of Q')
plot(Q,lambda1,Q,lambda2);
xlabel('Q')
ylabel('eigenvalues');
saveas(gcf,'lambda(Q).jpg');
figure('Name','Eigenvalues as functions of k')
plot(k,lambda1,k,lambda2);
xlabel('k')
ylabel('eigenvalues');
saveas(gcf,'lambda(k).jpg');


% ---------MEP SOLUTION-----------------
% We want to find the value of (Q*,Te*,Tp*) given by MEP (dependent on
% Op,Oe and s), to see if there is anything special with this value, when
% it comes to stability. From the entropy production and the equilbrium
% equations we have that:

Sdot = 2*Q*s^(1/4).*(1./(Op + Q).^(1/4) - 1./(Oe - 2*Q).^(1/4));
figure('Name', 'dS/dt wrt Q');
xlabel('Q')
ylabel('dS/dt');
plot(Q,Sdot);
saveas(gcf,'dS_dt(Q).jpg');

[C,I]=max(Sdot)     % Returns value, C, and index, I, of maximum Sdot
QMEP=Q(I)               % Uses this to find the corresponding Q-value
TeMEP=Te(I)
TpMEP=Tp(I)
kMEP=k(I)

% % The derivative of this wrt Q is (plotted to the screen)
% SdotdQ=s^(1/4)*(1./(Op + Q).^(1/4) - 1./(Oe - 2*Q).^(1/4)) - Q.*s^(1/4).*(1./(4*(Op + Q).^(5/4)) + 1./(2*(Oe - 2*Q).^(5/4)));
% figure('Name', 'd(dS/dt)dQ wrt Q');
% plot(Q,SdotdQ);











